==> patternfly-java-components-0.2.11.jar: org/patternfly/component/accordion/AccordionItemBody.java <==
/*
 *  Copyright 2023 Red Hat
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.patternfly.component.accordion;

import elemental2.dom.HTMLDivElement;

import static org.jboss.elemento.Elements.div;
import static org.patternfly.style.Classes.accordion;
import static org.patternfly.style.Classes.body;
import static org.patternfly.style.Classes.component;
import static org.patternfly.style.Classes.expandableContent;

public class AccordionItemBody extends AccordionSubComponent<HTMLDivElement, AccordionItemBody> {

    // ------------------------------------------------------ factory

    public static AccordionItemBody accordionItemBody() {
        return new AccordionItemBody();
    }

    // ------------------------------------------------------ instance

    static final String SUB_COMPONENT_NAME = "acicb";

    AccordionItemBody() {
        super(SUB_COMPONENT_NAME, div().css(component(accordion, expandableContent, body)).element());
    }

    // ------------------------------------------------------ builder

    @Override
    public AccordionItemBody that() {
        return this;
    }
}

==> patternfly-java-components-0.3.0.jar: org/patternfly/component/accordion/AccordionItemBody.java <==
/*
 *  Copyright 2023 Red Hat
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.patternfly.component.accordion;

import org.jboss.elemento.ElementTextMethods;

import elemental2.dom.HTMLDivElement;

import static org.jboss.elemento.Elements.div;
import static org.patternfly.style.Classes.accordion;
import static org.patternfly.style.Classes.body;
import static org.patternfly.style.Classes.component;
import static org.patternfly.style.Classes.expandableContent;

public class AccordionItemBody extends AccordionSubComponent<HTMLDivElement, AccordionItemBody> implements
        ElementTextMethods<HTMLDivElement, AccordionItemBody> {

    // ------------------------------------------------------ factory

    public static AccordionItemBody accordionItemBody() {
        return new AccordionItemBody();
    }

    // ------------------------------------------------------ instance

    static final String SUB_COMPONENT_NAME = "acicb";

    AccordionItemBody() {
        super(SUB_COMPONENT_NAME, div().css(component(accordion, expandableContent, body)).element());
    }

    // ------------------------------------------------------ builder

    @Override
    public AccordionItemBody that() {
        return this;
    }
}
